<?php

/**
 * @file
 * Admin pages for the webform_profile module.
 */

/**
 * The administrator pages for the Webform Profile module.
 */
function webform_profile_admin_form(&$form_state) {

  // Set the theme for this form.
  $form = array('#theme' => 'webform_profile_admin_form');

  // Store all of our field data.
  $fields = array();
  $enabled = array();
  $overridable = array();
  $autofill = array();

  $webform_nid = variable_get('webform_profile_webform', 0);

  // Get all webform nodes.
  $webform_types = webform_variable_get('webform_node_types');
  $placeholders = db_placeholders($webform_types, 'varchar');
  $webforms = db_query(
    "SELECT nid, title FROM {node} WHERE type IN ($placeholders) ORDER BY title",
    $webform_types
  );
  $webform_list = array();
  while ($webform = db_fetch_object($webforms)) {
    $webform_list[$webform->nid] = $webform->title;
  }

  // Iterate through our node types.
  if ($webform_nid > 0) {
    // Get all of the fields from the profile webform.
    $webform = webform_node_load(node_load($webform_nid));

    // Iterate through the content type fields.
    foreach ($webform['webform']['components'] as $field_id => $field) {

      // Don't include fieldsets.
      if ($field['type'] == 'fieldset') {
        continue;
      }

      // Include parent name in the title for clarification.
      if ($field['pid']) {
        $field['name'] = $webform['webform']['components'][$field['pid']]['name'] . ' - ' . $field['name'];
      }

      // Add this to our fields array.
      $fields[$field['form_key']] = $field;

      // Add our form options.
      $enabled[$field['form_key']] = '';
      $overridable[$field['form_key']] = '';
      $autofill[$field['form_key']] = '';
    }
  }

  // Add all webforms so the user can choose which is the profile webform.
  $form['webform_profile_webform'] = array(
    '#type' => 'select',
    '#title' => t('Select a webform to use for user profiles.'),
    '#options' => $webform_list,
    '#default_value' => variable_get('webform_profile_webform', NULL),
  );

  // Add the checkboxes for these submissions.
  $form['webform_profile_enabled'] = array(
    '#type' => 'checkboxes',
    '#options' => $enabled,
    '#default_value' => variable_get('webform_profile_enabled', array_keys($enabled)),
  );
  $form['webform_profile_overridable'] = array(
    '#type' => 'checkboxes',
    '#options' => $overridable,
    '#default_value' => variable_get('webform_profile_overridable', array_keys($overridable)),
  );
  $form['webform_profile_autofill'] = array(
    '#type' => 'checkboxes',
    '#options' => $autofill,
    '#default_value' => variable_get('webform_profile_autofill', array_keys($autofill)),
  );

  // Store the fields in this form.
  $form['#fields'] = array('#type' => 'value', '#value' => $fields);

  // Add a Save button.
  $form['buttons']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  $form['buttons']['reset'] = array(
    '#type' => 'submit',
    '#value' => t('Reset to defaults'),
  );

  // Add the typical system settings form submit handler.
  $form['#submit'][] = 'system_settings_form_submit';

  // Return the settings form.
  return $form;
}

/**
 * Theme the webform_profile_admin_form.
 */
function theme_webform_profile_admin_form($form) {
  $header = array('Field', 'Enabled', 'Overridable', 'AutoFill');
  $rows = array();

  $rows[] = array(
    '',
    'If checked, these profile fields will be enabled when creating webforms.',
    'If checked, these fields will be allowed to be overridden by the webform data.  Some data you may not want to allow the user to provide different data that is within their profile. ( such as Birthday ).',
    'If checked, these fields will autopopulate on the webform with the data within your profile.',
  );

  // Get the fields.
  $fields = $form['#fields']['#value'];

  // Iterate through all of our fields.
  foreach ($fields as $field_id => $field) {
    // Add this as a row showing the difference.
    $rows[] = array(
      $field['name'],
      drupal_render($form['webform_profile_enabled'][$field_id]),
      drupal_render($form['webform_profile_overridable'][$field_id]),
      drupal_render($form['webform_profile_autofill'][$field_id]),
    );
  }

  // Generate the output.
  $output = theme('select', $form['webform_profile_webform']);
  $output .= theme('table', $header, $rows);
  $output .= drupal_render($form);
  return $output;
}
